//gets the current Cloud SQL instance/project name for the sql connection
function getServerName_(){
  return app.a.a.a[13].sqlDatabase.split('/')[0];
}

//stored Cloud SQL credentials
function credentials_(){
  var url = 'jdbc:google:mysql://' + getServerName_();
  var username = '';
  var password = '';
  return {'url':url, 'username':username, 'password':password};
}

//gets the name of the current App Maker database
function getDatabaseName_(){
  return app.a.a.a[13].sqlDatabase.split('/').pop();
}

//escapes any characters that might interfere with mysql queries
function mysql_real_escape_string (str) {
    return !str ? str : str.replace(/[\0\x08\x09\x1a\n\r"'`\\\%]/g, function (char) {
        switch (char) {
            case "\0":
                return "\\0";
            case "\x08":
                return "\\b";
            case "\x09":
                return "\\t";
            case "\x1a":
                return "\\z";
            case "\n":
                return "\\n";
            case "\r":
                return "\\r";
            case "`":
                return "``";
            case "\"":
            case "'":
            case "\\":
            case "%":
                return "\\"+char;
        }
    });
}

//deletes the selected datbase
function deleteDatabase(databaseName){
  
  var query = app.models.database_notes.newQuery();
  query.filters.database_name._equals = databaseName;
  var records = query.run();
  app.deleteRecords(records);
  
  var creds = credentials_();
  var conn = Jdbc.getCloudSqlConnection(creds.url, creds.username, creds.password);
  var stmt = conn.prepareStatement('DROP DATABASE ' + mysql_real_escape_string(databaseName));

  stmt.executeUpdate();

  stmt.close();
  conn.close();
}


//gets the first 100 rows of the selected database table, optionally sorted
function get_data(database_name, table_name, sort_by, reverse){
  database_name = mysql_real_escape_string(database_name);
  table_name = mysql_real_escape_string(table_name);
  var desc = reverse === null ? '' : ' DESC';
  var order_by = sort_by === null ? '' : ' ORDER BY `' + table_name + '`.`' + mysql_real_escape_string(sort_by) + '`' + desc;
  var creds = credentials_();
  var conn = Jdbc.getCloudSqlConnection(creds.url, creds.username, creds.password);
  var stmt = conn.prepareStatement(
    'SELECT * FROM `' + database_name + '`.`' + table_name + '`' + order_by + ' LIMIT 100;'
  );

  var res = stmt.executeQuery();
  var records = [];
  var meta = res.getMetaData();
  var cols = meta.getColumnCount() + 1;
  
  var header = [];
  for(var i = 1; i < cols; i++){
    header.push(meta.getColumnName(i));
  }
  
  records.push(header);
  
  while(res.next()) {
    var record = [];
    for(i = 1; i < cols; i++){
      record.push(res.getString(i));
    }
    records.push(record);
  }

  res.close();
  stmt.close();
  conn.close();

  return JSON.stringify(records);  
}

//updates database notes
function update_database_notes(database_name, value){
  var query = app.models.database_notes.newQuery();
  query.filters.database_name._equals = database_name;
  var result = query.run();
  
  var record = result.length > 0 ? result[0] : app.models.database_notes.newRecord();
  
  record.notes = value;
  record.database_name = database_name;
  
  app.saveRecords([record]);
    
}











